@@ -10,7 +10,7 @@
  * This work is licensed under the terms of the GNU GPL, version 2.  See
  * the COPYING file in the top-level directory.
  *
- * SPDX-License-Identifier:	GPL-2.0
+ * SPDX-License-Identifier:	GPL-2.0-only
  */
 
 #include <efi.h>
@@ -31,7 +31,7 @@ VOID PrintC(const UINT8 color, const CHAR16 *fmt, ...)
 	(VOID) ST->ConOut->SetAttribute(ST->ConOut, attr);
 }
 
-BOOLEAN IsOnBootMedium(EFI_DEVICE_PATH *dp)
+static BOOLEAN IsOnBootMedium(EFI_DEVICE_PATH *dp)
 {
 	extern CHAR16 *boot_medium_path;
 	CHAR16 *device_path, *tmp;
@@ -108,7 +108,7 @@ EFI_STATUS get_volumes(VOLUME_DESC **volumes, UINTN *count)
 	EFI_HANDLE *handles = NULL;
 	EFI_GUID sfspGuid = SIMPLE_FILE_SYSTEM_PROTOCOL;
 	UINTN handleCount = 0;
-	UINTN index, rootCount = 0;
+	UINTN index, rootCount = 0, bootCount = 0;
 
 	EFI_FILE_HANDLE tmp;
 
@@ -133,7 +133,6 @@ EFI_STATUS get_volumes(VOLUME_DESC **volumes, UINTN *count)
 
 	for (index = 0; index < handleCount; index++) {
 		EFI_FILE_IO_INTERFACE *fs = NULL;
-		CHAR16 *devpathstr;
 
 		status = BS->HandleProtocol(
 		    handles[index], &sfspGuid, (VOID **)&fs);
@@ -155,26 +154,38 @@ EFI_STATUS get_volumes(VOLUME_DESC **volumes, UINTN *count)
 			ERROR(L"Could not get device path for config partition, skipping.\n");
 			continue;
 		}
-		devpathstr = DevicePathToStr(devpath);
 
-		(*volumes)[rootCount].root = tmp;
-		(*volumes)[rootCount].devpath = devpath;
-		(*volumes)[rootCount].fslabel =
-		    get_volume_label((*volumes)[rootCount].root);
-		(*volumes)[rootCount].fscustomlabel =
-		    get_volume_custom_label((*volumes)[rootCount].root);
-		INFO(L"Volume %d: ", rootCount);
-		if (IsOnBootMedium(devpath)) {
-			INFO(L"(On boot medium) ");
+		UINTN target = rootCount;
+		BOOLEAN onbootmedium = IsOnBootMedium(devpath);
+		if (onbootmedium) {
+			CopyMem(&(*volumes)[bootCount + 1], &(*volumes)[bootCount],
+				(rootCount - bootCount) * sizeof(VOLUME_DESC));
+			target = bootCount++;
 		}
-		INFO(L"%s, LABEL=%s, CLABEL=%s\n",
-		      devpathstr, (*volumes)[rootCount].fslabel,
-		      (*volumes)[rootCount].fscustomlabel);
 
-		FreePool(devpathstr);
+		(*volumes)[target].root = tmp;
+		(*volumes)[target].devpath = devpath;
+		(*volumes)[target].onbootmedium = onbootmedium;
+		(*volumes)[target].fslabel =
+		    get_volume_label((*volumes)[target].root);
+		(*volumes)[target].fscustomlabel =
+		    get_volume_custom_label((*volumes)[target].root);
 
 		rootCount++;
 	}
+
+	for (index = 0; index < rootCount; index++) {
+		INFO(L"Volume %d: ", index);
+		if ((*volumes)[index].onbootmedium) {
+			INFO(L"(On boot medium) ");
+		}
+		CHAR16 *devpathstr = DevicePathToStr((*volumes)[index].devpath);
+		INFO(L"%s, LABEL=%s, CLABEL=%s\n",
+		      devpathstr, (*volumes)[index].fslabel,
+		      (*volumes)[index].fscustomlabel);
+		FreePool(devpathstr);
+	}
+
 	*count = rootCount;
 	return EFI_SUCCESS;
 }
